extensions [nw array]
turtles-own
[
  node-clustering-coefficient
  distance-from-other-turtles   ;; list of distances of this node from other turtles
  race
  adopted?
]
links-own
[
  rewired?                    ;; keeps track of whether the link has been rewired or not
]
globals
[
  clustering-coefficient               ;; the clustering coefficient of the network; this is the
                                       ;; average of clustering coefficients of all turtles
  average-path-length                  ;; average path length of the network
  clustering-coefficient-of-lattice    ;; the clustering coefficient of the initial lattice
  average-path-length-of-lattice       ;; average path length of the initial lattice
  infinity                             ;; a very large number.
                                         ;; used to denote distance between two turtles which
                                         ;; don't have a connected or unconnected path between them
  highlight-string                     ;; message that appears on the node properties monitor
  number-rewired                       ;; number of edges that have been rewired. used for plots.
  rewire-one?                          ;; these two variables record which button was last pushed
  rewire-all?
  rewiring-probability
  
  diffusion-initiation-type
  homophilous-diffusion
  sticky?

  %-similar-green
  %-similar-red
  %-similar-total
  %-adopted-total
  %-adopted-green
  %-adopted-red
  average-degree
  
  mean-bwn-cntrl
  mean-close-cntrl
  
  #-weak-comp-clusters
  #-max-cliques
  #-biggest-max-cliques
  #-bicomponent
  maximum-degree
  max-degree
  max-degree-1
  max-degree-2
  onehalf-times-degree
  two-times-degree
  zero-degree
  one-degree
  two-degree
  
  degrees
  
  stopped
  
  seed
]

;;;;;;;;;;;;;;;;;;;;;;;;
;;; Setup Procedures ;;;
;;;;;;;;;;;;;;;;;;;;;;;;
to setup-network
  ca
  set seed random 1000000
  random-seed seed
  set infinity 99999  ;; just an arbitrary choice for a large number
  set-default-shape turtles "circle"
  make-turtles
  
  ;; set up a variable to determine if we still have a connected network
  ;; (in most cases we will since it starts out fully connected)
  let success? false
;  while [not success?] [
;    ;; we need to find initial values for lattice
    wire-them
;    ;;calculate average path length and clustering coefficient for the lattice
;    set success? do-calculations
;  ]

  ;; setting the values for the initial lattice
  set clustering-coefficient-of-lattice clustering-coefficient
  set average-path-length-of-lattice average-path-length
  set number-rewired 0
  set rewiring-probability .5
  set highlight-string ""
  
  update-%-similar
  rewire-all
  update-plots
end
to make-turtles
;;ordered assignment  
;  crt num-nodes / 2 [ set color green set race "g" set adopted? 0 set tried? 0 set exposed? 0 set randomized? 0]
;  crt num-nodes / 2 [ set color red set race "r" set adopted? 0 set tried? 0 set exposed? 0 set randomized? 0]

;;random assignment
  crt num-nodes
  ask n-of (num-nodes / 2) turtles [ set color green set race "g" set adopted? 0]
  ask turtles with [race != "g"] [ set color red set race "r" set adopted? 0]
  
  ;; arrange them in a circle in order by who number
  layout-circle (turtles) max-pxcor - 1
end
to setup-diffusion
  reset-ticks 
  set %-adopted-total %-initially-adopted
  set diffusion-initiation-type "from-inside"
  set homophilous-diffusion true
  set sticky? true
;  clear-all-plots
  ask turtles [set adopted? 0 set shape "circle" set size 1]
  initiate-diffusion
  update-%-adopted   
end
;;;;;;;;;;;;;;;;;;;;;;;
;;; Main Procedures ;;;
;;;;;;;;;;;;;;;;;;;;;;;
;;creates a homophilous network
to evolve
   let dummy-update-%-similar 0
   let connected? FALSE
   
   while [connected? = FALSE]
   [
     ;;stop when it reaches the equilbrium
     while [dummy-update-%-similar != %-similar-total]
     [
        set dummy-update-%-similar %-similar-total
        ask turtles [
          let my-race race
          if (count link-neighbors != 0)
          [
     
             if ( ( count link-neighbors with [race = my-race] / (count my-links)) < %-similar-wanted ) 
             [
            
  ;              let friends-of-my-friends-with-same-race [one-of link-neighbors with [race = my-race] ] of link-neighbors
  ;              set friends-of-my-friends-with-same-race remove self friends-of-my-friends-with-same-race
                
                nw:set-snapshot turtles links 
                let second-degree-similar-friends sort (nw:turtles-in-radius 2) with [race = my-race] 
                let friends sort (nw:turtles-in-radius 1)
                let prospective-friend one-of second-degree-similar-friends 
                let stopper 0 
                while [stopper < num-nodes] 
                [
                  ifelse (member? prospective-friend friends)
                    [set prospective-friend one-of second-degree-similar-friends set stopper stopper + 1]
                    [set stopper 2 * num-nodes]
                ] 
                if(stopper = num-nodes) [set prospective-friend nobody]
                
                ;;if you cannot find a new similar to you friend, then do not leave a dissimilar friend of you!
                if(prospective-friend != nobody) 
                [ ;homophilous tie formation
                  create-link-with prospective-friend                
                  ;homophilous tie dissolution
                  ask link-with one-of link-neighbors with [race != my-race] [die]
                ]         
              ]
           ]
        ]
        update-%-similar
     ]
     ;; not have seperate guys from the network
     ;ask turtles with [count link-neighbors = 0] [let my-race race create-link-with one-of other turtles with [race = my-race]]
     set connected? do-calculations
     ;;if the network is not connected than create a new one and let it evolve again
     if (not connected?)[rewire-all]
     update-%-similar
     update-plots
   ]
end
to start-diffusion
  ifelse (homophilous-diffusion)
  [
    ask turtles
    [
      let my-race race
      if(count link-neighbors with [race = my-race] != 0)
      [
       ifelse ( (count link-neighbors with [race = my-race and adopted? = 1] / count link-neighbors with [race = my-race] ) > adoption-threshold )
         [set adopted? 1 set shape "star" set size 2]
         ;;if non-sticky, then drop it! if sticky, you cannot drop!
         [if (not sticky?)[set adopted? 0 set shape "circle" set size 1]]
      ]
    ]
  ]
  ;non-homophilous diffusion
  [
    ask turtles
    [
     ifelse ( (count link-neighbors with [adopted? = 1] / count link-neighbors ) > adoption-threshold )
       [set adopted? 1 set shape "star" set size 2]
       ;;if non-sticky, then drop it! if sticky, you cannot drop!
       [if (not sticky?)[set adopted? 0 set shape "circle" set size 1]]
    ]
  ]
  update-%-adopted
  tick    
end

to initiate-diffusion  
  if(diffusion-initiation-type = "from-inside")
  [
    ask max-n-of (%-initially-adopted * num-nodes / 2) turtles with [race = "g"] [count my-links] [set adopted? 1 set shape "star" set size 2]
    ask max-n-of (%-initially-adopted * num-nodes / 2) turtles with [race = "r"] [count my-links] [set adopted? 1 set shape "star" set size 2]
  ]
  if(diffusion-initiation-type = "from-outside")
  [
    ask min-n-of (%-initially-adopted * num-nodes / 2) turtles with [race = "g"] [count my-links] [set adopted? 1 set shape "star" set size 2]
    ask min-n-of (%-initially-adopted * num-nodes / 2) turtles with [race = "r"] [count my-links] [set adopted? 1 set shape "star" set size 2]
  ]
  if(diffusion-initiation-type = "random")
  [
    ask n-of (%-initially-adopted * num-nodes / 2) turtles with [race = "g"] [set adopted? 1 set shape "star" set size 2]
    ask n-of (%-initially-adopted * num-nodes / 2) turtles with [race = "r"] [set adopted? 1 set shape "star" set size 2]
  ]
end
;;calculates the %-similar values
to update-%-similar
  let dummy1 0
  ask turtles with [race = "g"] [if (count my-links != 0) [set dummy1 dummy1 + (count link-neighbors with [race = "g"] / (count my-links))]]
  set %-similar-green dummy1 / count turtles with [race = "g"]

  let dummy2 0
  ask turtles with [race = "r"] [if (count my-links != 0) [set dummy2 dummy2 + (count link-neighbors with [race = "r"] / (count my-links))]]
  set %-similar-red dummy2 / count turtles with [race = "r"]

  set %-similar-total (%-similar-red + %-similar-green) / 2
end
to update-%-adopted
  set %-adopted-total 100 * (mean [adopted?] of turtles) 
  set %-adopted-green 100 * (mean [adopted?] of turtles with [race = "g"])   
  set %-adopted-red 100 * (mean [adopted?] of turtles with [race = "r"]) 
end
to layout
  ;; the number 3 here is arbitrary; more repetitions slows down the
  ;; model, but too few gives poor layouts
  repeat 3 [
    ;; the more turtles we have to fit into the same amount of space,
    ;; the smaller the inputs to layout-spring we'll need to use
    let factor layout-coefficient * sqrt count turtles
    ;; numbers here are arbitrarily chosen for pleasing appearance
    layout-spring turtles links (1 / factor) (5 / factor) (20 / factor)
    display  ;; for smooth animation
  ]
  ;; don't bump the edges of the world
  let x-offset max [xcor] of turtles + min [xcor] of turtles
  let y-offset max [ycor] of turtles + min [ycor] of turtles
  ;; big jumps look funny, so only adjust a little each time
  set x-offset limit-magnitude x-offset 0.25
  set y-offset limit-magnitude y-offset 0.25
  ask turtles [ setxy (xcor - x-offset / 2) (ycor - y-offset / 2) ]
end

to-report limit-magnitude [number limit]
  if number > limit [ report limit ]
  if number < (- limit) [ report (- limit) ]
  report number
end
to rewire-all  
  
  ;; make sure num-turtles is setup correctly; if not run setup first
  if count turtles != num-nodes [
    setup-network
  ]

  ;; record which button was pushed
  set rewire-one? false
  set rewire-all? true

  ;; set up a variable to see if the network is connected
  let success? false

  ;; if we end up with a disconnected network, we keep trying, because the APL distance
  ;; isn't meaningful for a disconnected network.
  while [not success?] [
    ; kill the old lattice, reset neighbors, and create new lattice
    ask links [ die ]
    wire-them
    set number-rewired 0
    
    ask links [

      ;whether to rewire it or not?
      if (random-float 1 < rewiring-probability) 
      [
      ;"a" remains the same
        let node1 end1
      ;if "a" is not connected to everybody
        if [ count link-neighbors ] of end1 < (count turtles - 1)
        [
      ;find a node distinct from node1 and not already a neighbor of node1
          let node2 one-of turtles with [ (self != node1) and (not link-neighbor? node1) ]
      ;wire the new edge
          ask node1 [ create-link-with node2 [ set color cyan  set rewired? true ] ]

          set number-rewired number-rewired + 1  ;; counter for number of rewirings
          set rewired? true
        ]
      ]
      ;remove the old edge
      if (rewired?)
      [
        die
      ]
    ]

    ; check to see if the new network is connected and calculate path length and clustering
    ; coefficient at the same time

    ;set success? do-calculations
    set success? true
  ]
  update-%-similar
  ;; do the plotting
  update-plots
end

;; do-calculations reports true if the network is connected,
;;   and reports false if the network is disconnected.
;; (in the disconnected case, the average path length does not make sense,
;;   or perhaps may be considered infinite)
to-report do-calculations

  ;; set up a variable so we can report if the network is disconnected
  let connected? true

  ;; find the path lengths in the network
  find-path-lengths

  let num-connected-pairs sum [length remove infinity (remove 0 distance-from-other-turtles)] of turtles

  ;; in a connected network on N nodes, we should have N(N-1) measurements of distances between pairs,
  ;; and none of those distances should be infinity.
  ;; if there were any "infinity" length paths between nodes, then the network is disconnected.
  ;; in that case, calculating the average-path-length doesn't really make sense.
  ifelse ( num-connected-pairs != (count turtles * (count turtles - 1) ))
  [
      set average-path-length infinity
      ;; report that the network is not connected
      set connected? false
  ]
  [
    set average-path-length (sum [sum distance-from-other-turtles] of turtles) / (num-connected-pairs)
  ]
  ;; find the clustering coefficient and add to the aggregate for all iterations
  find-clustering-coefficient
  ;; find the average degree of the network
  set average-degree mean [count link-neighbors] of turtles
  ;; report whether the network is connected or not
  
  nw:set-snapshot turtles links
  set mean-bwn-cntrl mean [ nw:betweenness-centrality ] of turtles
  set mean-close-cntrl mean [ nw:closeness-centrality ] of turtles
  
  report connected?
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Clustering computations ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to-report in-neighborhood? [ hood ]
  report ( member? end1 hood and member? end2 hood )
end


to find-clustering-coefficient
  ifelse all? turtles [count link-neighbors <= 1]
  [
    ;; it is undefined
    ;; what should this be?
    set clustering-coefficient 0
  ]
  [
    let total 0
    ask turtles with [ count link-neighbors <= 1]
      [ set node-clustering-coefficient "undefined" ]
    ask turtles with [ count link-neighbors > 1]
    [
      let hood link-neighbors
      set node-clustering-coefficient (2 * count links with [ in-neighborhood? hood ] /
                                         ((count hood) * (count hood - 1)) )
      ;; find the sum for the value at turtles
      set total total + node-clustering-coefficient
    ]
    ;; take the average
    set clustering-coefficient total / count turtles with [count link-neighbors > 1]
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Path length computations ;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; implements the Floyd Warshall algorithm for All Pairs Shortest Paths
;; it is a dynamic programming algorithm which builds bigger solutions
;; from the solutions of smaller subproblems using memoization that
;; is storing the results.
;; it keeps finding incrementally if there is shorter path through
;; the kth node.
;; Since it iterates over all turtles through k,
;; so at the end we get the shortest possible path for each i and j.

to find-path-lengths
  ;; reset the distance list
  ask turtles
  [
    set distance-from-other-turtles []
  ]

  let i 0
  let j 0
  let k 0
  let node1 one-of turtles
  let node2 one-of turtles
  let node-count count turtles
  ;; initialize the distance lists
  while [i < node-count]
  [
    set j 0
    while [j < node-count]
    [
      set node1 turtle i
      set node2 turtle j
      ;; zero from a node to itself
      ifelse i = j
      [
        ask node1 [
          set distance-from-other-turtles lput 0 distance-from-other-turtles
        ]
      ]
      [
        ;; 1 from a node to it's neighbor
        ifelse [ link-neighbor? node1 ] of node2
        [
          ask node1 [
            set distance-from-other-turtles lput 1 distance-from-other-turtles
          ]
        ]
        ;; infinite to everyone else
        [
          ask node1 [
            set distance-from-other-turtles lput infinity distance-from-other-turtles
          ]
        ]
      ]
      set j j + 1
    ]
    set i i + 1
  ]
  set i 0
  set j 0
  let dummy 0
  while [k < node-count]
  [
    set i 0
    while [i < node-count]
    [
      set j 0
      while [j < node-count]
      [
        ;; alternate path length through kth node
        set dummy ( (item k [distance-from-other-turtles] of turtle i) +
                    (item j [distance-from-other-turtles] of turtle k))
        ;; is the alternate path shorter?
        if dummy < (item j [distance-from-other-turtles] of turtle i)
        [
          ask turtle i [
            set distance-from-other-turtles replace-item j distance-from-other-turtles dummy
          ]
        ]
        set j j + 1
      ]
      set i i + 1
    ]
    set k k + 1
  ]

end

;;;;;;;;;;;;;;;;;;;;;;;
;;; Edge Operations ;;;
;;;;;;;;;;;;;;;;;;;;;;;

;; creates a new lattice
to wire-them
  ;; iterate over the turtles
  let n 0
  while [n < count turtles]
  [
    ;; make edges with the next average-degree-wanted/2 neighbors
    ;; this makes a lattice with average degree of average-degree-wanted
    let i 1
    while [i <= (average-degree-wanted / 2)]
    [
    make-edge turtle n
              turtle ((n + i) mod count turtles)
    set i i + 1          
    ]
    set n n + 1
  ]
end

;; connects the two turtles
to make-edge [node1 node2]
  ask node1 [ create-link-with node2  [
    set rewired? false
  ] ]
end
; Copyright 2013 Mustafa Yavas. mustafa.yavas@boun.edu.tr or mustafa.yavas@yale.edu
@#$#@#$#@
GRAPHICS-WINDOW
335
10
835
531
20
20
11.9535
1
10
1
1
1
0
0
0
1
-20
20
-20
20
0
0
1
ticks
30.0

SLIDER
920
110
1060
143
num-nodes
num-nodes
0
1000
100
20
1
NIL
HORIZONTAL

SLIDER
920
145
1060
178
%-similar-wanted
%-similar-wanted
0
1
0.3
0.01
1
NIL
HORIZONTAL

MONITOR
215
20
335
65
NIL
clustering-coefficient
3
1
11

MONITOR
215
65
335
110
NIL
average-path-length
3
1
11

BUTTON
835
110
915
143
setup-network
setup-network
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
75
20
195
65
%-similar-red
%-similar-red
3
1
11

MONITOR
75
65
195
110
%-similar-green
%-similar-green
3
1
11

MONITOR
75
110
195
155
%-similar-total
%-similar-total
3
1
11

BUTTON
835
145
915
178
evolve
evolve
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
835
180
915
213
layout
layout
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
920
180
1060
213
layout-coefficient
layout-coefficient
0.0005
0.75
0.75
0.0005
1
NIL
HORIZONTAL

MONITOR
215
110
335
155
average-degree
average-degree
3
1
11

SLIDER
835
75
1060
108
average-degree-wanted
average-degree-wanted
2
12
6
2
1
NIL
HORIZONTAL

BUTTON
835
375
1015
408
start-diffusion
start-diffusion
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
835
270
1015
303
%-initially-adopted
%-initially-adopted
0
1
0.1
0.01
1
NIL
HORIZONTAL

PLOT
25
330
205
465
Adoption Rate
Time
% adopted
0.0
16.0
0.0
100.0
false
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot %-adopted-total"
"pen-1" 1.0 0 -10899396 true "" "plot %-adopted-green"
"pen-2" 1.0 0 -2674135 true "" "plot %-adopted-red"

BUTTON
835
340
1015
373
setup-diffusion
setup-diffusion
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
215
330
335
375
%-adopted-total
%-adopted-total
3
1
11

MONITOR
215
420
335
465
NIL
%-adopted-green
3
1
11

MONITOR
215
375
335
420
NIL
%-adopted-red
3
1
11

SLIDER
835
305
1015
338
adoption-threshold
adoption-threshold
0
1
0.3
0.01
1
NIL
HORIZONTAL

PLOT
75
165
335
320
Degree Distribution
NIL
NIL
0.0
20.0
0.0
20.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" "histogram [count my-links] of turtles"

TEXTBOX
850
50
1060
81
Network formation and evolution
13
0.0
1

TEXTBOX
855
245
1005
263
Diffusion
13
0.0
1

@#$#@#$#@
## COPYRIGHT AND LICENSE

Copyright 2013 Mustafa Yavas. mustafa.yavas@boun.edu.tr or mustafa.yavas@yale.edu

NOTE: To be able to run the model, "nw" network extension package should be downloaded. It can be found in the following link:
https://github.com/NetLogo/NW-Extension
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.3
@#$#@#$#@
setup
repeat 5 [rewire-one]
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="vary-rewiring-probability" repetitions="5" runMetricsEveryStep="false">
    <go>rewire-all</go>
    <timeLimit steps="1"/>
    <exitCondition>rewiring-probability &gt; 1</exitCondition>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <steppedValueSet variable="rewiring-probability" first="0" step="0.025" last="1"/>
  </experiment>
  <experiment name="experiment2.5" repetitions="100" runMetricsEveryStep="false">
    <setup>macrosetup</setup>
    <go>start-diffusion</go>
    <timeLimit steps="14"/>
    <exitCondition>%-adopted-total = 100 or %-adopted-total = 0</exitCondition>
    <metric>%-adopted-total</metric>
    <metric>%-similar-total</metric>
    <metric>clustering-coefficient</metric>
    <metric>seed</metric>
    <enumeratedValueSet variable="%-similar-adopted-to-adopt">
      <value value="0.25"/>
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-similar-wanted">
      <value value="0.5"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sticky?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="homophilous-diffusion">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree-wanted">
      <value value="4"/>
      <value value="6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment December 2 2012" repetitions="200" runMetricsEveryStep="false">
    <setup>macrosetup</setup>
    <go>start-diffusion</go>
    <timeLimit steps="15"/>
    <exitCondition>%-adopted-total = 100 or %-adopted-total = 0</exitCondition>
    <metric>%-adopted-total</metric>
    <metric>mean [tried?] of turtles</metric>
    <metric>mean [exposed?] of turtles</metric>
    <metric>%-similar-total</metric>
    <metric>clustering-coefficient</metric>
    <metric>average-path-length</metric>
    <metric>seed</metric>
    <enumeratedValueSet variable="homophilous-diffusion">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sticky?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-adopted-to-adopt">
      <value value="0.3"/>
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-similar-wanted">
      <value value="0"/>
      <value value="0.4"/>
      <value value="0.6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment December 3 2012" repetitions="200" runMetricsEveryStep="false">
    <setup>macrosetup</setup>
    <go>start-diffusion</go>
    <timeLimit steps="15"/>
    <exitCondition>%-adopted-total = 100 or %-adopted-total = 0</exitCondition>
    <metric>%-adopted-total</metric>
    <metric>mean [tried?] of turtles</metric>
    <metric>mean [exposed?] of turtles</metric>
    <metric>%-similar-total</metric>
    <metric>clustering-coefficient</metric>
    <metric>average-path-length</metric>
    <metric>seed</metric>
    <enumeratedValueSet variable="homophilous-diffusion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sticky?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-adopted-to-adopt">
      <value value="0.3"/>
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-similar-wanted">
      <value value="0"/>
      <value value="0.4"/>
      <value value="0.6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="robustness check1 December 3 2012" repetitions="100" runMetricsEveryStep="false">
    <setup>macrosetup</setup>
    <go>start-diffusion</go>
    <timeLimit steps="15"/>
    <exitCondition>%-adopted-total = 100 or %-adopted-total = 0</exitCondition>
    <metric>%-adopted-total</metric>
    <metric>mean [tried?] of turtles</metric>
    <metric>mean [exposed?] of turtles</metric>
    <metric>%-similar-total</metric>
    <metric>clustering-coefficient</metric>
    <metric>average-path-length</metric>
    <metric>seed</metric>
    <enumeratedValueSet variable="homophilous-diffusion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sticky?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-adopted-to-adopt">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-similar-wanted">
      <value value="0"/>
      <value value="0.4"/>
      <value value="0.6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="robustness check400 December 3 2012" repetitions="400" runMetricsEveryStep="false">
    <setup>macrosetup</setup>
    <go>start-diffusion</go>
    <timeLimit steps="15"/>
    <exitCondition>%-adopted-total = 100 or %-adopted-total = 0</exitCondition>
    <metric>%-adopted-total</metric>
    <metric>mean [tried?] of turtles</metric>
    <metric>mean [exposed?] of turtles</metric>
    <metric>%-similar-total</metric>
    <metric>clustering-coefficient</metric>
    <metric>average-path-length</metric>
    <metric>seed</metric>
    <enumeratedValueSet variable="homophilous-diffusion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sticky?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-adopted-to-adopt">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-similar-wanted">
      <value value="0"/>
      <value value="0.4"/>
      <value value="0.6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="robustness check200 December 3 2012" repetitions="200" runMetricsEveryStep="false">
    <setup>macrosetup</setup>
    <go>start-diffusion</go>
    <timeLimit steps="15"/>
    <exitCondition>%-adopted-total = 100 or %-adopted-total = 0</exitCondition>
    <metric>%-adopted-total</metric>
    <metric>mean [tried?] of turtles</metric>
    <metric>mean [exposed?] of turtles</metric>
    <metric>%-similar-total</metric>
    <metric>clustering-coefficient</metric>
    <metric>average-path-length</metric>
    <metric>seed</metric>
    <enumeratedValueSet variable="homophilous-diffusion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sticky?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-adopted-to-adopt">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-similar-wanted">
      <value value="0"/>
      <value value="0.4"/>
      <value value="0.6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="robustness check500 December 3 2012" repetitions="500" runMetricsEveryStep="false">
    <setup>macrosetup</setup>
    <go>start-diffusion</go>
    <timeLimit steps="30"/>
    <exitCondition>%-adopted-total = 100 or %-adopted-total = 0</exitCondition>
    <metric>%-adopted-total</metric>
    <metric>mean [tried?] of turtles</metric>
    <metric>mean [exposed?] of turtles</metric>
    <metric>%-similar-total</metric>
    <metric>clustering-coefficient</metric>
    <metric>average-path-length</metric>
    <metric>seed</metric>
    <enumeratedValueSet variable="homophilous-diffusion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sticky?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-adopted-to-adopt">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-similar-wanted">
      <value value="0"/>
      <value value="0.4"/>
      <value value="0.6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="robustness check800 December 3 2012" repetitions="800" runMetricsEveryStep="false">
    <setup>macrosetup</setup>
    <go>start-diffusion</go>
    <timeLimit steps="30"/>
    <exitCondition>%-adopted-total = 100 or %-adopted-total = 0</exitCondition>
    <metric>%-adopted-total</metric>
    <metric>mean [tried?] of turtles</metric>
    <metric>mean [exposed?] of turtles</metric>
    <metric>%-similar-total</metric>
    <metric>clustering-coefficient</metric>
    <metric>average-path-length</metric>
    <metric>seed</metric>
    <enumeratedValueSet variable="homophilous-diffusion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sticky?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-adopted-to-adopt">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-similar-wanted">
      <value value="0"/>
      <value value="0.4"/>
      <value value="0.6"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="1000 December 17 2012" repetitions="1000" runMetricsEveryStep="false">
    <setup>macrosetup</setup>
    <go>start-diffusion</go>
    <timeLimit steps="30"/>
    <exitCondition>%-adopted-total = 100 or %-adopted-total = 0</exitCondition>
    <metric>%-adopted-total</metric>
    <metric>%-similar-total</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <metric>mean [tried?] of turtles</metric>
    <metric>mean [exposed?] of turtles</metric>
    <metric>seed</metric>
    <enumeratedValueSet variable="average-degree-wanted">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-nodes">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="homophilous-diffusion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sticky?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-adopted-to-adopt">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-similar-wanted">
      <value value="0"/>
      <value value="0.2"/>
      <value value="0.25"/>
      <value value="0.3"/>
      <value value="0.35"/>
      <value value="0.4"/>
      <value value="0.45"/>
      <value value="0.5"/>
      <value value="0.55"/>
      <value value="0.6"/>
      <value value="0.65"/>
      <value value="0.7"/>
      <value value="0.75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Avg. Deg. 500 December 18 2012" repetitions="500" runMetricsEveryStep="false">
    <setup>macrosetup</setup>
    <go>start-diffusion</go>
    <timeLimit steps="30"/>
    <exitCondition>%-adopted-total = 100 or %-adopted-total = 0</exitCondition>
    <metric>%-adopted-total</metric>
    <metric>%-similar-total</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <metric>mean [tried?] of turtles</metric>
    <metric>mean [exposed?] of turtles</metric>
    <metric>seed</metric>
    <enumeratedValueSet variable="average-degree-wanted">
      <value value="6"/>
      <value value="8"/>
      <value value="10"/>
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-nodes">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="homophilous-diffusion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sticky?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-adopted-to-adopt">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-similar-wanted">
      <value value="0"/>
      <value value="0.35"/>
      <value value="0.65"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Avg. Degree 8-10, 250 December 19 2012" repetitions="250" runMetricsEveryStep="false">
    <setup>macrosetup</setup>
    <go>start-diffusion</go>
    <timeLimit steps="30"/>
    <exitCondition>%-adopted-total = 100 or %-adopted-total = 0</exitCondition>
    <metric>%-adopted-total</metric>
    <metric>%-similar-total</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <metric>mean [tried?] of turtles</metric>
    <metric>mean [exposed?] of turtles</metric>
    <metric>seed</metric>
    <enumeratedValueSet variable="average-degree-wanted">
      <value value="8"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-nodes">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rewiring-probability">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="homophilous-diffusion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sticky?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-adopted-to-adopt">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-similar-wanted">
      <value value="0"/>
      <value value="0.2"/>
      <value value="0.25"/>
      <value value="0.3"/>
      <value value="0.35"/>
      <value value="0.4"/>
      <value value="0.45"/>
      <value value="0.5"/>
      <value value="0.55"/>
      <value value="0.6"/>
      <value value="0.65"/>
      <value value="0.7"/>
      <value value="0.75"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="all 500 December 22 2012" repetitions="500" runMetricsEveryStep="false">
    <setup>macrosetup</setup>
    <go>start-diffusion</go>
    <timeLimit steps="30"/>
    <exitCondition>%-adopted-total = 100 or %-adopted-total = 0</exitCondition>
    <metric>%-adopted-total</metric>
    <metric>%-similar-total</metric>
    <metric>average-path-length</metric>
    <metric>clustering-coefficient</metric>
    <metric>mean-bwn-cntrl</metric>
    <metric>mean-close-cntrl</metric>
    <metric>mean-eigen-cntrl</metric>
    <metric>mean [tried?] of turtles</metric>
    <metric>mean [exposed?] of turtles</metric>
    <metric>seed</metric>
    <enumeratedValueSet variable="average-degree-wanted">
      <value value="6"/>
      <value value="8"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-nodes">
      <value value="100"/>
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rewiring-probability">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="homophilous-diffusion">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sticky?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-adopted-to-adopt">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-similar-wanted">
      <value value="0"/>
      <value value="0.2"/>
      <value value="0.25"/>
      <value value="0.3"/>
      <value value="0.35"/>
      <value value="0.4"/>
      <value value="0.45"/>
      <value value="0.5"/>
      <value value="0.55"/>
      <value value="0.6"/>
      <value value="0.65"/>
      <value value="0.7"/>
      <value value="0.75"/>
      <value value="0.8"/>
      <value value="0.85"/>
      <value value="0.9"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="network 500 December 28 2012" repetitions="500" runMetricsEveryStep="false">
    <setup>disconnected-setup</setup>
    <exitCondition>stopped = 1</exitCondition>
    <metric>clustering-coefficient</metric>
    <metric>mean-bwn-cntrl</metric>
    <metric>mean-close-cntrl</metric>
    <metric>#-weak-comp-clusters</metric>
    <metric>#-max-cliques</metric>
    <metric>#-biggest-max-cliques</metric>
    <metric>#-bicomponent</metric>
    <metric>average-degree</metric>
    <metric>maximum-degree</metric>
    <metric>max-degree</metric>
    <metric>max-degree-1</metric>
    <metric>max-degree-2</metric>
    <metric>onehalf-times-degree</metric>
    <metric>two-times-degree</metric>
    <metric>zero-degree</metric>
    <metric>one-degree</metric>
    <metric>two-degree</metric>
    <metric>seed</metric>
    <enumeratedValueSet variable="average-degree-wanted">
      <value value="6"/>
      <value value="8"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-nodes">
      <value value="100"/>
      <value value="200"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rewiring-probability">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-similar-wanted">
      <value value="0"/>
      <value value="0.2"/>
      <value value="0.25"/>
      <value value="0.3"/>
      <value value="0.35"/>
      <value value="0.4"/>
      <value value="0.45"/>
      <value value="0.5"/>
      <value value="0.55"/>
      <value value="0.6"/>
      <value value="0.65"/>
      <value value="0.7"/>
      <value value="0.75"/>
      <value value="0.8"/>
      <value value="0.85"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="deg 10, 100 nodes 500 December 30 2012" repetitions="20" runMetricsEveryStep="false">
    <setup>disconnected-setup</setup>
    <exitCondition>stopped = 1</exitCondition>
    <metric>degrees</metric>
    <metric>clustering-coefficient</metric>
    <metric>mean-bwn-cntrl</metric>
    <metric>mean-close-cntrl</metric>
    <metric>#-weak-comp-clusters</metric>
    <metric>#-max-cliques</metric>
    <metric>#-biggest-max-cliques</metric>
    <metric>#-bicomponent</metric>
    <metric>average-degree</metric>
    <metric>maximum-degree</metric>
    <metric>max-degree</metric>
    <metric>max-degree-1</metric>
    <metric>max-degree-2</metric>
    <metric>onehalf-times-degree</metric>
    <metric>two-times-degree</metric>
    <metric>zero-degree</metric>
    <metric>one-degree</metric>
    <metric>two-degree</metric>
    <metric>seed</metric>
    <enumeratedValueSet variable="average-degree-wanted">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-nodes">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rewiring-probability">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-similar-wanted">
      <value value="0"/>
      <value value="0.2"/>
      <value value="0.25"/>
      <value value="0.3"/>
      <value value="0.35"/>
      <value value="0.4"/>
      <value value="0.45"/>
      <value value="0.5"/>
      <value value="0.55"/>
      <value value="0.6"/>
      <value value="0.65"/>
      <value value="0.7"/>
      <value value="0.75"/>
      <value value="0.8"/>
      <value value="0.85"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="deg 8, 100 nodes 500 Jan 8 2013" repetitions="500" runMetricsEveryStep="false">
    <setup>macrosetup</setup>
    <go>start-diffusion</go>
    <timeLimit steps="30"/>
    <exitCondition>%-adopted-total = 100 or %-adopted-total = 0</exitCondition>
    <metric>%-adopted-total</metric>
    <metric>clustering-coefficient</metric>
    <metric>average-path-length</metric>
    <metric>mean-bwn-cntrl</metric>
    <metric>mean-close-cntrl</metric>
    <metric>mean[tried?] of turtles</metric>
    <metric>mean[exposed?] of turtles</metric>
    <metric>seed</metric>
    <enumeratedValueSet variable="average-degree-wanted">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-nodes">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rewiring-probability">
      <value value="0.2"/>
      <value value="0.4"/>
      <value value="0.6"/>
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-similar-wanted">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="homophilous-diffusion">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="rewire , deg 8, 100 nodes 500 Jan 8 2013" repetitions="500" runMetricsEveryStep="false">
    <setup>macrosetup</setup>
    <go>start-diffusion</go>
    <timeLimit steps="30"/>
    <exitCondition>%-adopted-total = 100 or %-adopted-total = 0</exitCondition>
    <metric>%-adopted-total</metric>
    <metric>clustering-coefficient</metric>
    <metric>average-path-length</metric>
    <metric>%-similar-total</metric>
    <metric>mean-bwn-cntrl</metric>
    <metric>mean-close-cntrl</metric>
    <metric>mean[tried?] of turtles</metric>
    <metric>mean[exposed?] of turtles</metric>
    <metric>seed</metric>
    <enumeratedValueSet variable="average-degree-wanted">
      <value value="8"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-nodes">
      <value value="100"/>
      <value value="200"/>
    </enumeratedValueSet>
    <steppedValueSet variable="rewiring-probability" first="0" step="0.1" last="1"/>
    <enumeratedValueSet variable="%-similar-wanted">
      <value value="0"/>
      <value value="0.3"/>
      <value value="0.65"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="homophilous-diffusion">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
1
@#$#@#$#@
